@@ -3,13 +3,13 @@ package Net::DNS::Parameters;
 ################################################
 ##
 ##	Domain Name System (DNS) Parameters
-##	(last updated 2021-03-08)
+##	(last updated 2022-04-01)
 ##
 ################################################
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: Parameters.pm 1832 2021-03-22 08:33:36Z willem $)[2];
+our $VERSION = (qw$Id: Parameters.pm 1865 2022-05-21 09:57:49Z willem $)[2];
 
 use integer;
 use Carp;
@@ -72,34 +72,34 @@ my @typebyname = (
 	ISDN	   => 20,					# RFC1183
 	RT	   => 21,					# RFC1183
 	NSAP	   => 22,					# RFC1706
-	'NSAP-PTR' => 23,					# RFC1348 RFC1637 RFC1706
-	SIG	   => 24,					# RFC4034 RFC3755 RFC2535 RFC2536 RFC2537 RFC2931 RFC3110 RFC3008
-	KEY	   => 25,					# RFC4034 RFC3755 RFC2535 RFC2536 RFC2537 RFC2539 RFC3008 RFC3110
+	'NSAP-PTR' => 23,					# RFC1706
+	SIG	   => 24,					# RFC2536 RFC2931 RFC3110 RFC4034
+	KEY	   => 25,					# RFC2536 RFC2539 RFC3110 RFC4034
 	PX	   => 26,					# RFC2163
 	GPOS	   => 27,					# RFC1712
 	AAAA	   => 28,					# RFC3596
 	LOC	   => 29,					# RFC1876
-	NXT	   => 30,					# RFC3755 RFC2535
+	NXT	   => 30,					# RFC2535 RFC3755
 	EID	   => 31,					# http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt
 	NIMLOC	   => 32,					# http://ana-3.lcs.mit.edu/~jnc/nimrod/dns.txt
 	SRV	   => 33,					# RFC2782
 	ATMA	   => 34,					# http://www.broadband-forum.org/ftp/pub/approved-specs/af-dans-0152.000.pdf
-	NAPTR	   => 35,					# RFC2915 RFC2168 RFC3403
+	NAPTR	   => 35,					# RFC3403
 	KX	   => 36,					# RFC2230
 	CERT	   => 37,					# RFC4398
-	A6	   => 38,					# RFC3226 RFC2874 RFC6563
+	A6	   => 38,					# RFC2874 RFC3226 RFC6563
 	DNAME	   => 39,					# RFC6672
-	SINK	   => 40,					# http://tools.ietf.org/html/draft-eastlake-kitchen-sink
-	OPT	   => 41,					# RFC6891 RFC3225
+	SINK	   => 40,					# draft-eastlake-kitchen-sink
+	OPT	   => 41,					# RFC3225 RFC6891
 	APL	   => 42,					# RFC3123
-	DS	   => 43,					# RFC4034 RFC3658
+	DS	   => 43,					# RFC4034
 	SSHFP	   => 44,					# RFC4255
 	IPSECKEY   => 45,					# RFC4025
-	RRSIG	   => 46,					# RFC4034 RFC3755
-	NSEC	   => 47,					# RFC4034 RFC3755
-	DNSKEY	   => 48,					# RFC4034 RFC3755
+	RRSIG	   => 46,					# RFC4034
+	NSEC	   => 47,					# RFC4034 RFC9077
+	DNSKEY	   => 48,					# RFC4034
 	DHCID	   => 49,					# RFC4701
-	NSEC3	   => 50,					# RFC5155
+	NSEC3	   => 50,					# RFC5155 RFC9077
 	NSEC3PARAM => 51,					# RFC5155
 	TLSA	   => 52,					# RFC6698
 	SMIMEA	   => 53,					# RFC8162
@@ -207,7 +207,8 @@ my @ednsoptionbyname = (
 	'EXTENDED-ERROR' => 15,					# RFC8914
 	'CLIENT-TAG'	 => 16,					# draft-bellis-dnsop-edns-tags
 	'SERVER-TAG'	 => 17,					# draft-bellis-dnsop-edns-tags
-	DEVICEID	 => 26946,				# https://docs.umbrella.com/developer/networkdevices-api/identifying-dns-traffic2
+	'UMBRELLA-IDENT' => 20292,				# https://developer.cisco.com/docs/cloud-security/#!integrating-network-devic
+	DEVICEID	 => 26946,				# https://developer.cisco.com/docs/cloud-security/#!network-devices-getting-s
 	);
 our %ednsoptionbyval = reverse @ednsoptionbyname;
 push @ednsoptionbyname, map { /^\d/ ? $_ : lc($_) } @ednsoptionbyname;
@@ -359,48 +360,41 @@ sub dsotypebyval {
 }
 
 
-sub register {				## register( 'TOY', 1234 )	(NOT part of published API)
-	my ( $mnemonic, $rrtype ) = @_;				# uncoverable pod
-	$rrtype = rand(255) + 65280 unless $rrtype;
-	croak qq["$mnemonic" is a CLASS identifier] if defined $classbyname{$mnemonic = uc($mnemonic)};
-	for ( typebyval( $rrtype = int $rrtype ) ) {
-		return $rrtype if /^$mnemonic$/;		# duplicate registration
-		croak qq["$mnemonic" conflicts with TYPE$rrtype ($_)] unless /^TYPE\d+$/;
-		my $known = $typebyname{$mnemonic};
-		croak qq["$mnemonic" conflicts with TYPE$known] if $known;
-	}
-	$typebyval{$rrtype} = $mnemonic;
-	return $typebyname{$mnemonic} = $rrtype;
-}
-
-
 use constant EXTLANG => defined eval { require Net::DNS::Extlang };
 
-our $DNSEXTLANG = EXTLANG ? eval { Net::DNS::Extlang->new()->domain } : undef;
-
 sub _typespec {
-	eval {				## draft-levine-dnsextlang
-		<<'END' } if EXTLANG && $DNSEXTLANG;
-	my ($node) = @_;
+	my $generate = defined wantarray;
+	return EXTLANG ? eval <<'END' : '';			# no critic
+	my ($node) = @_;		## draft-levine-dnsextlang
+	my $instance = Net::DNS::Extlang->new();
+	my $basename = $instance->domain || return '';
 
 	require Net::DNS::Resolver;
-	my $resolver = Net::DNS::Resolver->new() || return;
-	my $response = $resolver->send( "$node.$DNSEXTLANG", 'TXT' ) || return;
+	my $resolver = Net::DNS::Resolver->new();
+	my $response = $resolver->send( "$node.$basename", 'TXT' ) || return '';
 
 	foreach my $txt ( grep { $_->type eq 'TXT' } $response->answer ) {
 		my @stanza = $txt->txtdata;
 		my ( $tag, $identifier, @attribute ) = @stanza;
 		next unless defined($tag) && $tag =~ /^RRTYPE=\d+$/;
-		register( $1, $2 ) if $identifier =~ /^(\w+):(\d+)\W*/;
-		return unless defined wantarray;
+		if ( $identifier =~ /^(\w+):(\d+)\W*/ ) {
+			my ( $mnemonic, $rrtype ) = ( uc($1), $2 );
+			croak qq["$mnemonic" is a CLASS identifier] if $classbyname{$mnemonic};
+			for ( typebyval($rrtype) ) {
+				next if /^$mnemonic$/i;		# duplicate registration
+				croak qq["$mnemonic" conflicts with TYPE$rrtype ($_)] unless /^TYPE\d+$/;
+				my $known = $typebyname{$mnemonic};
+				croak qq["$mnemonic" conflicts with TYPE$known] if $known;
+				$typebyval{$rrtype} = $mnemonic;
+				$typebyname{$mnemonic} = $rrtype;
+			}
+		}
+		return unless $generate;
 
-		my $extobj = Net::DNS::Extlang->new();
-		my $recipe = $extobj->xlstorerecord( $identifier, @attribute );
-		my @source = split /\n/, $extobj->compilerr($recipe);
-		return sub { defined( $_ = shift @source ) };
+		my $recipe = $instance->xlstorerecord( $identifier, @attribute );
+		return $instance->compilerr($recipe);
 	}
 END
-	return;
 }
 
 
@@ -453,7 +447,7 @@ All rights reserved.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
