@@ -1,22 +1,18 @@
 package Net::DNS::RR::A;
 
-#
-# $Id: A.pm 1597 2017-09-22 08:04:02Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: A.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::A - DNS A resource record
 
 =cut
 
-
 use integer;
 
 
@@ -25,20 +21,21 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 	my ( $data, $offset ) = @_;
 
 	$self->{address} = unpack "\@$offset a4", $$data;
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	pack 'a4', $self->{address};
+	return pack 'a4', $self->{address};
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	$self->address;
+	return $self->address;
 }
 
 
@@ -46,21 +43,21 @@ sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->address(shift);
+	return;
 }
 
 
 my $pad = pack 'x4';
 
 sub address {
-	my $self = shift;
-	my $addr = shift;
+	my ( $self, $addr ) = @_;
 
 	return join '.', unpack 'C4', $self->{address} . $pad unless defined $addr;
 
 	# Note: pack masks overlarge values, mostly without warning
 	my @part = split /\./, $addr;
 	my $last = pop(@part);
-	$self->{address} = pack 'C4', @part, (0) x ( 3 - @part ), $last;
+	return $self->{address} = pack 'C4', @part, (0) x ( 3 - @part ), $last;
 }
 
 
@@ -71,9 +68,9 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name IN A address');
+    $rr = Net::DNS::RR->new('name IN A address');
 
-    $rr = new Net::DNS::RR(
+    $rr = Net::DNS::RR->new(
 	name	=> 'example.com',
 	type	=> 'A',
 	address => '192.0.2.1'
@@ -114,7 +111,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
