@@ -2,7 +2,7 @@ package Net::DNS::RR::NSEC3;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: NSEC3.pm 1814 2020-10-14 21:49:16Z willem $)[2];
+our $VERSION = (qw$Id: NSEC3.pm 1857 2021-12-07 13:38:02Z willem $)[2];
 
 use base qw(Net::DNS::RR::NSEC);
 
@@ -24,38 +24,6 @@ require Net::DNS::DomainName;
 
 eval { require Digest::SHA };		## optional for simple Net::DNS RR
 
-my %digest = (
-	'1' => ['Digest::SHA', 1],				# RFC3658
-	);
-
-{
-	my @digestbyname = (
-		'SHA-1' => 1,					# RFC3658
-		);
-
-	my @digestalias = ( 'SHA' => 1 );
-
-	my %digestbyval = reverse @digestbyname;
-
-	foreach (@digestbyname) { s/[\W_]//g; }			# strip non-alphanumerics
-	my @digestrehash = map { /^\d/ ? ($_) x 3 : uc($_) } @digestbyname;
-	my %digestbyname = ( @digestalias, @digestrehash );	# work around broken cperl
-
-	sub _digestbyname {
-		my $arg = shift;
-		my $key = uc $arg;				# synthetic key
-		$key =~ s/[\W_]//g;				# strip non-alphanumerics
-		my $val = $digestbyname{$key};
-		croak qq[unknown algorithm "$arg"] unless defined $val;
-		return $val;
-	}
-
-	sub _digestbyval {
-		my $value = shift;
-		return $digestbyval{$value} || return $value;
-	}
-}
-
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
 	my $self = shift;
@@ -91,7 +59,7 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my @rdata = (
-		$self->algorithm, $self->flags, $self->iterations,
+		$self->algorithm,   $self->flags,    $self->iterations,
 		$self->salt || '-', $self->hnxtname, $self->typelist
 		);
 	return @rdata;
@@ -255,6 +223,38 @@ sub wildcard { return shift->{wildcard}; }
 
 ########################################
 
+my @digestbyname = (
+	'SHA-1' => 1,						# [RFC3658]
+	);
+
+my @digestalias = ( 'SHA' => 1 );
+
+my %digestbyval = reverse @digestbyname;
+
+foreach (@digestbyname) { s/[\W_]//g; }				# strip non-alphanumerics
+my @digestrehash = map { /^\d/ ? ($_) x 3 : uc($_) } @digestbyname;
+my %digestbyname = ( @digestalias, @digestrehash );		# work around broken cperl
+
+sub _digestbyname {
+	my $arg = shift;
+	my $key = uc $arg;					# synthetic key
+	$key =~ s/[\W_]//g;					# strip non-alphanumerics
+	my $val = $digestbyname{$key};
+	croak qq[unknown algorithm $arg] unless defined $val;
+	return $val;
+}
+
+sub _digestbyval {
+	my $value = shift;
+	return $digestbyval{$value} || return $value;
+}
+
+
+my %digest = (
+	'1' => scalar( eval { Digest::SHA->new(1) } ),		# RFC3658
+	);
+
+
 sub _decode_base32hex {
 	local $_ = shift || '';
 	tr [0-9A-Va-v\060-\071\101-\126\141-\166] [\000-\037\012-\037\000-\037\012-\037];
@@ -278,17 +278,12 @@ sub _hashfn {
 	my $iterations = shift || 0;
 	my $salt       = shift || '';
 
-	my $key_adjunct = pack 'Cna*', $hashalg, $iterations, $salt;
-	$iterations++;
+	my $hash = $digest{$hashalg};
+	return sub { croak "algorithm $hashalg not supported" }
+			unless $hash;
+	my $clone = $hash->clone;
 
-	my $instance = eval {
-		my $arglist = $digest{$hashalg};
-		my ( $class, @argument ) = @$arglist;
-		$class->new(@argument);
-	};
-	my $exception = $@;
-	return sub { croak $exception }
-			if $exception;
+	my $key_adjunct = pack 'Cna*', $hashalg, $iterations, $salt;
 
 	return sub {
 		my $name  = Net::DNS::DomainName->new(shift)->canonical;
@@ -297,15 +292,16 @@ sub _hashfn {
 		return $cache if defined $cache;
 		( $cache1, $cache2, $limit ) = ( {}, $cache1, 50 ) unless $limit--;    # recycle cache
 
-		my $hash = $name;
-		my $iter = $iterations;
-		$instance->reset;
-		while ( $iter-- ) {
-			$instance->add($hash);
-			$instance->add($salt);
-			$hash = $instance->digest;
+		$clone->add($name);
+		$clone->add($salt);
+		my $digest = $clone->digest;
+		my $count  = $iterations;
+		while ( $count-- ) {
+			$clone->add($digest);
+			$clone->add($salt);
+			$digest = $clone->digest;
 		}
-		return $$cache1{$key} = $hash;
+		return $$cache1{$key} = $digest;
 	};
 }
 
@@ -321,6 +317,8 @@ sub name2hash {
 	return _encode_base32hex( &$hash($name) );
 }
 
+########################################
+
 
 1;
 __END__
@@ -483,7 +481,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -500,7 +498,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC5155, RFC4648
+L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC5155, RFC9077
 
 L<Hash Algorithms|http://www.iana.org/assignments/dnssec-nsec3-parameters>
 
