@@ -1,22 +1,18 @@
 package Net::DNS::RR::OPENPGPKEY;
 
-#
-# $Id: OPENPGPKEY.pm 1597 2017-09-22 08:04:02Z willem $
-#
-our $VERSION = (qw$LastChangedRevision: 1597 $)[1];
-
-
 use strict;
 use warnings;
+our $VERSION = (qw$Id: OPENPGPKEY.pm 1857 2021-12-07 13:38:02Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::OPENPGPKEY - DNS OPENPGPKEY resource record
 
 =cut
 
-
 use integer;
 
 use MIME::Base64;
@@ -28,13 +24,14 @@ sub _decode_rdata {			## decode rdata from wire-format octet string
 
 	my $length = $self->{rdlength};
 	$self->keybin( substr $$data, $offset, $length );
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	pack 'a*', $self->keybin;
+	return pack 'a*', $self->keybin;
 }
 
 
@@ -42,6 +39,7 @@ sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
 	my @base64 = split /\s+/, encode_base64( $self->keybin );
+	return @base64;
 }
 
 
@@ -49,13 +47,14 @@ sub _parse_rdata {			## populate RR from rdata in argument list
 	my $self = shift;
 
 	$self->key(@_);
+	return;
 }
 
 
 sub key {
 	my $self = shift;
 	return MIME::Base64::encode( $self->keybin(), "" ) unless scalar @_;
-	$self->keybin( MIME::Base64::decode( join "", @_ ) );
+	return $self->keybin( MIME::Base64::decode( join "", @_ ) );
 }
 
 
@@ -63,7 +62,7 @@ sub keybin {
 	my $self = shift;
 
 	$self->{keybin} = shift if scalar @_;
-	$self->{keybin} || "";
+	return $self->{keybin} || "";
 }
 
 
@@ -74,7 +73,7 @@ __END__
 =head1 SYNOPSIS
 
     use Net::DNS;
-    $rr = new Net::DNS::RR('name OPENPGPKEY key');
+    $rr = Net::DNS::RR->new('name OPENPGPKEY key');
 
 =head1 DESCRIPTION
 
@@ -119,7 +118,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
